Client
------

An implementation of a client which interacts with deployed ML Servers.

Note: It is entirely possible to implement a client yourself, in another language.


Client
======

Client for interacting with the ML Server

.. automodule:: gordo.client.client
    :members:
    :undoc-members:
    :show-inheritance:


Forwarders
===========

Objects to be optionally provided to the Client which forwards the resulting
predictions.

.. automodule:: gordo.client.forwarders
    :members:
    :undoc-members:
    :show-inheritance:

IO
==

IO helpers used internally by the Client

.. automodule:: gordo.client.io
    :members:
    :undoc-members:
    :show-inheritance:


Utils
=====

General utility functions for the Client

.. automodule:: gordo.client.utils
    :members:
    :undoc-members:
    :show-inheritance:
